@@ -22,6 +22,6 @@ def ExtractFrames(video_path, directory, extractframerate=30):
   print("-----------Frame extraction completed-----------")
   return frames, newpath
 
-if __name__ == "__main__"
+if __name__ == "__main__":
     import sys
     ExtractFrames(sys.argv[1], sys.argv[2])
\ No newline at end of file
